pub enum Text {
Utf8(String),
Other(Vec<u8>),
}Expand description
The MIDI spec does not state what encoding should be used for strings. Since Rust strings are
UTF-8 encoded, we try to parse text as a String and hope for the best. But if we get an error
then we store the original bytes to facilitate lossless parsing.
Variants
Utf8(String)
A UTF-8 encoded string.
Other(Vec<u8>)
Some bytes that we don’t understand, probably a string in some non-UTF-8 encoding.
Implementations